#
# spec file for package goldendict
#
# Copyright (c) 2022 SUSE LLC
# Copyright 2013 Tvangeste <i.4m.l33t@yandex.ru>
# Copyright 2011-2022 <opensuse.lietuviu.kalba@gmail.com>
# Copyright 2021 <coder53@gmail.com>
# Copyright 2008-2009 Buschmann <buschmann23@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           goldendict
Summary:        Dictionary Lookup Program
License:        GPL-3.0-or-later
Group:          Productivity/Office/Dictionary
URL:            http://goldendict.org/
Version:        1.5.0~rc2+git.20220215T203220
Release:        bp155.3.12
Source0:        goldendict-%{version}.tar.xz
Patch1:         https://github.com/goldendict/goldendict/commit/8acb288c9e9bdb3c6bf2e803954dd3b6ac273c05.patch
Patch2:         https://github.com/goldendict/goldendict/commit/7fa7ad6e529a58173d0f3f2b0b73f12a316b5cc8.patch

BuildRequires:  desktop-file-utils
BuildRequires:  gcc-c++
BuildRequires:  git
BuildRequires:  hunspell-devel >= 1.2.4
BuildRequires:  libbz2-devel
BuildRequires:  libtiff-devel
BuildRequires:  lzo-devel
BuildRequires:  unzip
BuildRequires:  update-desktop-files
BuildRequires:  xz
BuildRequires:  pkgconfig(libzip)
BuildRequires:  pkgconfig(vorbis)
BuildRequires:  pkgconfig(xtst)
BuildRequires:  pkgconfig(zlib)
# Qt 5
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Help)
BuildRequires:  pkgconfig(Qt5Multimedia)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5PrintSupport)
BuildRequires:  pkgconfig(Qt5Sql)
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(Qt5WebEngineWidgets)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5X11Extras)
BuildRequires:  pkgconfig(Qt5Xml)
BuildRequires:  pkgconfig(x11)
# AV
BuildRequires:  libao-devel
BuildRequires:  pkgconfig(libavformat)
#BuildRequires:  libavutil-devel
#BuildRequires:  libffmpeg-devel
# eb-devel / libeb-dev for epwing. Otherwise use "CONFIG+=no_epwing_support"
%if 0%{?is_opensuse}
BuildRequires:  eb-devel
%endif
# Zstd compression required for optional ZIM format support. It can be enabled by "CONFIG+=zim_support"
BuildRequires:  pkgconfig(libzstd)

%description
Feature-rich dictionary lookup program.
    * Support of multiple dictionary file formats:
      * Babylon .BGL files
      * StarDict .ifo/.dict/.idx/.syn dictionaries
      * Dictd .index/.dict(.dz) dictionary files
      * ABBYY Lingvo .dsl source files
      * ABBYY Lingvo .lsa/.dat audio archives
    * Support for Wikipedia, Wiktionary or any other MediaWiki-based sites
    * Scan popup functionality. A small window pops up with translation of a
      word chosen from antoher application.
    * Full-text search.

%lang_package

%prep
%autosetup -p1
git init
%if 0%{?suse_version} < 1550
  # For Qt5.12 compatibility in openSUSE Leap 15.3
  find -name '*.cc' -exec sed -i 's/Qt::SkipEmptyParts/QString::SkipEmptyParts/g' {} +
  find -name '*.cc' -exec sed -i 's/errorOccurred/error/g' {} +
%endif

%build
%if 0%{?is_opensuse}
  %qmake5 PREFIX=%{_prefix} "CONFIG+=zim_support" goldendict.pro
%else
  %qmake5 PREFIX=%{_prefix} "CONFIG+=no_ffmpeg_player" "CONFIG+=no_epwing_support" \
    "CONFIG+=zim_support" goldendict.pro
%endif
%make_jobs

%install
%qmake5_install
%suse_update_desktop_file -r org.goldendict.GoldenDict Office Dictionary

%files
%license LICENSE.txt
%{_bindir}/%{name}
%{_datadir}/%{name}
%{_datadir}/applications/org.goldendict.GoldenDict.desktop
%{_datadir}/metainfo/org.goldendict.GoldenDict.metainfo.xml
%{_datadir}/pixmaps/%{name}.png
%exclude %{_datadir}/%{name}/locale/

%files lang
%{_datadir}/%{name}/locale/

%changelog
* Wed Jul 13 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Add 8acb288c9e9bdb3c6bf2e803954dd3b6ac273c05.patch and
  7fa7ad6e529a58173d0f3f2b0b73f12a316b5cc8.patch:
  Fix build with ffmpeg 5, patches from upstream git.
* Wed Feb 16 2022 <opensuse.lietuviu.kalba@gmail.com>
- Add _service file.
- Update to 1.5.0~rc2+git.20220215T203220 version:
  - Fixed navigation in popup window (Qt5WebEngine regression).
* Sun Feb  6 2022 Jan Engelhardt <jengelh@inai.de>
- Remove historic specfile constructs.
* Sun Feb  6 2022 <opensuse.lietuviu.kalba@gmail.com>
- Switch to github.com/xiaoyifang/goldendict.git specific branch
  "feature/qwebengine-port"
- Update to version 1.5.0~rc2+git.20220204T091209:
  - Fixed print preview.
* Wed Jan  5 2022 <opensuse.lietuviu.kalba@gmail.com>
- Update to version 1.5.0~rc2+git.20220104T210116:
  Fixed some regressions related to opening of links to other words
  of dictionaries.
* Fri Dec 31 2021 <opensuse.lietuviu.kalba@gmail.com>
- Switch to GoldenDict variant with Qt5WebEngine
  github.com/xiaoyifang/goldendict.git because original
  github.com/goldendict/goldendict is with deprecated Qt5WebKit.
- Update source to goldendict-1.5.0~rc2+git.20211231T234821
* Sat Apr 11 2020 opensuse.lietuviu.kalba@gmail.com
- Update source to goldendict-1.5.0~rc2+git.20200409T192512
  (i.e. a378acc0df33ff33f6f961b706894559bc5849b0).
- Use a better workaround for Wayland crashes.
- Update Brazilian Portuguese language.
* Thu Mar 19 2020 opensuse.lietuviu.kalba@gmail.com
- Update source to goldendict-1.5.0~rc2+git.20200319T123945
  (i.e. db93bd19d335c60cdf1ae9095709d03423e0f2b2).
- Remove RPM source files for Debian build.
- Fix some crashes under Qt 5.12.
- Added a desktop action as a workaround to crashes on Wayland.
- Normalize whitespaces while translate on clipboard change.
- appdata.xml: Pass appstream-util validation.
- Fix some data races.
- Fix Qt5-specific crash after Ctrl+Tab when tabs navigation in
  MRU order is turned on in preferences.
- FFmpeg player: Fix some crashes on broken files.
- Add ".webp", ".mpa", ".mp2" and ".opus" as known media.
- DSL: Trim spaces in "s" and "url" tags.
- DSL: Fix expanding of round brackets while full-text search.
- DSL: Strip tags "<<" and ">>" while full-text search.
- DSL: Fix handling of dsl "@" subcard in first line of card.
- DSL: Change of tags handling while full-text search.
- DSL: Fix sound saving from preferred dictionary.
- DSL: Fix {(...)} case handling in insided cards.
- Fix "file://" urls correction for case of launch portable GD
  via network.
- Increase limit of node elements while build index.
- SLOB: Some optimization for indexing of a large files.
- SLOB: Fix detection of article duplicates.
- SLOB: Add class "slobdict" to slob headword.
- SLOB: Add support for uncompressed articles.
- Allow dictionaries groups combobox standard hotkeys from FTS and
  Headwords dialogs.
- Fix empty menu if program compiled with qt5.
- XDXF: A little more handling for <ex> tag.
- XDXF: Fix indexing of the dictionaries with empty "abbreviation"
  field.
- Support "[!a-x]" like construction while handling wildcards
  via QRegularExpression.
- Use QRegularExpression instead of QRegExp in dictionary headwords
  dialog under Qt 5.12 and later.
- Fix save/restore geometry for some dialogs under Qt 5.12.
- Added AppData manifest file for modern package managers.
- Add Hindi, Lojban translations.
- Update Bulgarian, German, Lithuanian, Swedish, Turkish translations.
* Wed Aug  7 2019 Dead Mozay <dead_mozay@opensuse.org>
- Split -lang package
* Sun Mar  3 2019 Andrey Karepin <egdfree@opensuse.org>
- update source to e7e37cb
* Sun Mar  3 2019 Andrey Karepin <egdfree@opensuse.org>
- fix build in spec
- don't use CONFIG+=old_hunspell with libhunspell 1.6
* Wed Jun  6 2018 opensuse.lietuviu.kalba@gmail.com
- Fix GCC 7.3 compiler warnings.
- Fix headwords search for case of wildcard in the first position.
- ScanPopup:
  - Add button to stay over all other windows.
  - Add an option to disable scan popup inside Goldendict in Linux
- Full-test search:
  - Allow ignore diacritics while search.
  - Use dictionary-specific articles sorting while search
  - Add option to ignore words order while full-text search.
  - DSL: Handle round brackets while full-text search.
  - DSL: Expand tildes while full-text search
  - Fix full-text search for case of partially matched sequence.
- Add QMediaPlayer internal player back end (Qt5 only).
- Forvo: order pronunciations by rate, high rated first.
- Add ".webm" extension to known video types.
- Add partial support for "audio" tag in Stardict(html), GSL.
- Wiki: Fix parsing of "audio" tags.
- Wiki: Fix handling of url's without urls scheme.
- Wiki: Fix work with headwords containing the '+' sign.
- Handle BOM's for UTF-8 and UTF-16 encoding in programs output.
- Improve X11 autostart behavior.
- Implement "inactive dictionaries" feature for all groups.
- Update help system.
- Update translations.
* Sun Jun  4 2017 opensuse.lietuviu.kalba@gmail.com
- Update to 1.5.0 RC2 version
- Remove install-paths.patch
- Remove goldendict-gcc47.patch
* Sun Mar  5 2017 opensuse.lietuviu.kalba@gmail.com
- Build with Qt5 for openSUSE Leap 42 and newer openSUSE versions,
  also for SUSE 12 SP2 or newer. Other versions will still use Qt4.
* Sun Mar 18 2012 dimstar@opensuse.org
- Add goldendict-gcc47.patch: Fix build with gcc 4.7.
* Wed Oct 12 2011 opensuse.lietuviu.kalba@gmail.com
- remove licenses from requires section
- use 1291478773 git revision (version 1.0.1)
* Tue Nov 16 2010 dmitry@roshchin.org
- update to fresh git sources
* Sat Sep 18 2010 dmitry@roshchin.org
- update to fresh git sources
- add languages in spec file
* Fri Aug 20 2010 opensuse.lietuviu.kalba@gmail.com
- update to fresh git sources
- including lt_LT, uk_UA and ar_SA languages
  Mon Dec 21 19:14:57 CET 2009 - Elmar Stellnberger
- update to fresh git sources resolving frequent SIGSEGV-crashes
- goldendict-0.9.0-gcc44.patch no longer needes
- advance install-path patch
* Wed Sep 16 2009 buschmann23@opensuse.org
- fixed desktop file category
* Wed Sep 16 2009 buschmann23@opensuse.org
- added goldendict-0.9.0-gcc44.patch
- renamed instal-paths.patch to install-paths.patch
* Mon Sep 14 2009 buschmann23@opensuse.org
- BuildRequires hunspell-devel >= 1.2.4, and also requires
  hunspell >= 1.2.4 to run
* Wed Jul  8 2009 buschmann23@opensuse.org
- initial package
- version 0.9.0
